@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "toml" "0.4.0"
+(define-package "toml" "20250729.635"
   "TOML (Tom's Obvious, Minimal Language) parser."
   ()
   :url "https://github.com/gongo/emacs-toml"
-  :commit "aea330f33f922c50e108aeca4e83159ca5da8556"
-  :revdesc "0.4.0-0-gaea330f33f92"
+  :commit "8d8cefa2a0590ed4b68064a7a55a552c0a16a68a"
+  :revdesc "8d8cefa2a059"
   :keywords '("toml" "parser")
   :authors '(("Wataru MIYAGUNI" . "gonngo@gmail.com"))
   :maintainers '(("Wataru MIYAGUNI" . "gonngo@gmail.com")))
